summaryrefslogtreecommitdiffstats
path: root/src/3rdparty/phonon
diff options
context:
space:
mode:
authorFrans Englich <frans.englich@nokia.com>2009-07-21 14:09:27 (GMT)
committerFrans Englich <frans.englich@nokia.com>2009-07-21 14:09:27 (GMT)
commit1e08ccc646e4f07fd560c901ff7b56626ed98d1e (patch)
treeca7e1fe5036fa3008dcceb6e7fb7d60cbdfba5ab /src/3rdparty/phonon
parent7bd7c88d4e555131af035cb7262a5b0b663f63f0 (diff)
downloadQt-1e08ccc646e4f07fd560c901ff7b56626ed98d1e.zip
Qt-1e08ccc646e4f07fd560c901ff7b56626ed98d1e.tar.gz
Qt-1e08ccc646e4f07fd560c901ff7b56626ed98d1e.tar.bz2
Crash fixes.
Diffstat (limited to 'src/3rdparty/phonon')
-rw-r--r--src/3rdparty/phonon/mmf/audiooutput.h8
-rw-r--r--src/3rdparty/phonon/mmf/mediaobject.h1
2 files changed, 6 insertions, 3 deletions
diff --git a/src/3rdparty/phonon/mmf/mediaobject.h b/src/3rdparty/phonon/mmf/mediaobject.h
index ae3cbeb..0631e4a 100644
--- a/src/3rdparty/phonon/mmf/mediaobject.h
+++ b/src/3rdparty/phonon/mmf/mediaobject.h
@@ -52,6 +52,7 @@ namespace Phonon
{
Q_OBJECT
Q_INTERFACES(Phonon::MediaObjectInterface)
+
public:
MediaObject(QObject *parent);
virtual ~MediaObject();
diff --git a/src/3rdparty/phonon/mmf/audiooutput.h b/src/3rdparty/phonon/mmf/audiooutput.h
index 02dd046..8c0de1f 100644
--- a/src/3rdparty/phonon/mmf/audiooutput.h
+++ b/src/3rdparty/phonon/mmf/audiooutput.h
@@ -29,9 +29,9 @@ namespace Phonon
class MediaObject;
/**
* @short AudioOutputInterface42 implementation for MMF.
*
* Implements the AudioOutputInterface42 for Symbian/S60's MMF
* framework.
*
* This class has a very small role, we simply access CDrmPlayerUtility
@@ -47,9 +47,11 @@ namespace Phonon
* @author Frans Englich<frans.englich@nokia.com>
*/
class AudioOutput : public QObject
- , public AudioOutputInterface42
+ , public AudioOutputInterface
{
Q_OBJECT
+ Q_INTERFACES(Phonon::AudioOutputInterface)
+
public:
AudioOutput(Backend *backend, QObject *parent);
virtual qreal volume() const;
@@ -29,9 +29,9 @@ namespace Phonon
class MediaObject;
/**
- * @short AudioOutputInterface42 implementation for MMF.
+ * @short AudioOutputInterface implementation for MMF.
*
@@ -29,9 +29,9 @@ namespace Phonon
*
- * Implements the AudioOutputInterface42 for Symbian/S60's MMF
+ * Implements the AudioOutputInterface for Symbian/S60's MMF
* framework.
*